@@ -249,9 +249,9 @@ def parseargs(argv):
         if options.output is not None:
             log('--output option is ignored in backup mode')
             options.output = None
-        if options.withverify is not None:
+        if options.withverify:
             log('--with-verify option is ignored in backup mode')
-            options.withverify = None
+            options.withverify = False
         if not options.file:
             usage(1, '--file is required in backup mode')
     elif options.mode == RECOVER:
@@ -281,9 +281,9 @@ def parseargs(argv):
         if options.killold:
             log('--kill-old-on-full option is ignored in verify mode')
             options.killold = False
-        if options.withverify is not None:
+        if options.withverify:
             log('--with-verify option is ignored in verify mode')
-            options.withverify = None
+            options.withverify = False
     return options
 
 
@@ -578,7 +578,7 @@ def do_incremental_backup(options, reposz, repofiles):
                               gen_filename(options, '.index', tnow))
     fs._index.save(pos, index_file)
     fs.close()
-    log('writing incremental: %s bytes to %s',  pos-reposz, dest)
+    log('writing incremental: %s bytes to %s', pos - reposz, dest)
     sum = copyfile(options, dest, reposz, pos - reposz)
     # The first file in repofiles points to the last full backup.  Use this to
     # get the .dat file and append the information for this incrementatl to
@@ -617,7 +617,7 @@ def do_backup(options):
         # incremental's start and stop positions.
         srcfp = open(options.file, 'rb')
         srcfp.seek(startpos)
-        srcsum = checksum(srcfp, endpos-startpos)
+        srcsum = checksum(srcfp, endpos - startpos)
         srcfp.close()
         log('last incremental file: %s', fn)
         log('last incremental checksum: %s', sum)
@@ -685,7 +685,7 @@ def do_recover(options):
     files_to_close = ()
     if options.output is None:
         log('Recovering file to stdout')
-        outfp = sys.stdout
+        outfp = sys.stdout.buffer
     else:
         # Delete old ZODB before recovering backup as size of
         # old ZODB + full partial file may be superior to free disk space
@@ -788,8 +788,8 @@ def do_verify(options):
             elif not options.quick:
                 if actual_sum != sum:
                     raise VerificationFail(
-                        "%s has checksum %s%s instead of %s" % (
-                            filename, actual_sum, when_uncompressed, sum))
+                        f"{filename} has checksum {actual_sum}"
+                        f"{when_uncompressed} instead of {sum}")
 
 
 def get_checksum_and_size_of_gzipped_file(filename, quick):
