@@ -35,6 +35,7 @@ from ZODB._compat import dump
 from ZODB._compat import dumps
 from ZODB.Connection import TransactionMetaData
 from ZODB.fsIndex import fsIndex
+from ZODB.interfaces import IStorageWrapper
 from ZODB.tests import BasicStorage
 from ZODB.tests import ConflictResolution
 from ZODB.tests import Corruption
@@ -140,13 +141,13 @@ class FileStorageTests(
 
         # Convert it to a dict.
         old_index = self.convert_index_to_dict()
-        self.assertTrue(isinstance(old_index, fsIndex))
+        self.assertIsInstance(old_index, fsIndex)
         new_index = self.convert_index_to_dict()
-        self.assertTrue(isinstance(new_index, dict))
+        self.assertIsInstance(new_index, dict)
 
         # Verify it's converted to fsIndex in memory upon open.
         self.open(read_only=read_only)
-        self.assertTrue(isinstance(self._storage._index, fsIndex))
+        self.assertIsInstance(self._storage._index, fsIndex)
 
         # Verify it has the right content.
         newindex_as_dict = dict(self._storage._index)
@@ -156,9 +157,9 @@ class FileStorageTests(
         self._storage.close()
         current_index = self.convert_index_to_dict()
         if read_only:
-            self.assertTrue(isinstance(current_index, dict))
+            self.assertIsInstance(current_index, dict)
         else:
-            self.assertTrue(isinstance(current_index, fsIndex))
+            self.assertIsInstance(current_index, fsIndex)
 
     def test_conversion_to_fsIndex_readonly(self):
         # Same thing, but the disk .index should continue to hold a
@@ -189,8 +190,8 @@ class FileStorageTests(
 
         # Verify it's converted to fsIndex in memory upon open.
         self.open()
-        self.assertTrue(isinstance(self._storage._index, fsIndex))
-        self.assertTrue(isinstance(self._storage._index._data, OOBTree))
+        self.assertIsInstance(self._storage._index, fsIndex)
+        self.assertIsInstance(self._storage._index._data, OOBTree)
 
         # Verify it has the right content.
         new_data_dict = dict(self._storage._index._data)
@@ -218,7 +219,7 @@ class FileStorageTests(
         giant_oid = b'\xee' * 8
         # Store an object.
         # oid, serial, data, version, transaction
-        self._storage.store(giant_oid, b'\0'*8, b'data', b'', t)
+        self._storage.store(giant_oid, b'\0' * 8, b'data', b'', t)
         # Finish the transaction.
         self._storage.tpc_vote(t)
         self._storage.tpc_finish(t)
@@ -235,13 +236,53 @@ class FileStorageTests(
         giant_oid = b'\xee' * 8
         # Store an object.
         # oid, serial, data, version, prev_txn, transaction
-        self._storage.restore(giant_oid, b'\0'*8, b'data', b'', None, t)
+        self._storage.restore(giant_oid, b'\0' * 8, b'data', b'', None, t)
         # Finish the transaction.
         self._storage.tpc_vote(t)
         self._storage.tpc_finish(t)
         # Before ZODB 3.2.6, this failed, with ._oid == z64.
         self.assertEqual(self._storage._oid, giant_oid)
 
+    def testRestoreCopy(self):
+        # Verify that restore with prev_txn restores data record with
+        # backpointer to prev_txn.
+        oid = p64(1)
+
+        t = TransactionMetaData()
+        self._storage.tpc_begin(t)
+        self._storage.store(oid, z64, b'data rev 1', b'', t)
+        self._storage.tpc_vote(t)
+        self._storage.tpc_finish(t)
+        rev1 = self._storage.lastTransaction()
+
+        rev2 = p64(U64(rev1) + 1)
+        t = TransactionMetaData()
+        self._storage.tpc_begin(t, rev2)
+        # restore should write data record with backpointer to rev1
+        self._storage.restore(oid, rev2, b'data rev 1', b'', rev1, t)
+        self._storage.tpc_vote(t)
+        self._storage.tpc_finish(t)
+        self.assertEqual(self._storage.lastTransaction(), rev2)
+
+        # locate rev2 data record and verify it is backpointer to rev1
+        pos2 = self._storage._lookup_pos(oid)
+        h2 = self._storage._read_data_header(pos2, oid)
+        self.assertEqual(h2.oid, oid)
+        self.assertEqual(h2.tid, rev2)
+        self.assertEqual(h2.plen, 0)
+        self.assertNotEqual(h2.back, 0)
+
+        h1 = self._storage._read_data_header(h2.back, oid)
+        self.assertEqual(h1.oid, oid)
+        self.assertEqual(h1.tid, rev1)
+        self.assertNotEqual(h1.plen, 0)
+        self.assertEqual(h1.back, 0)
+
+        data1 = self._storage._file.read(h1.plen)
+        if IStorageWrapper.providedBy(self._storage):
+            data1 = self._storage.untransform_record_data(data1)
+        self.assertEqual(data1, b'data rev 1')
+
     def testCorruptionInPack(self):
         # This sets up a corrupt .fs file, with a redundant transaction
         # length mismatch.  The implementation of pack in many releases of
@@ -285,8 +326,11 @@ class FileStorageTests(
         try:
             self._storage.pack(time.time(), referencesf)
         except CorruptedError as detail:
-            self.assertTrue("redundant transaction length does not match "
-                            "initial transaction length" in str(detail))
+            self.assertIn(
+                "redundant transaction length does not match "
+                "initial transaction length",
+                str(detail)
+            )
         else:
             self.fail("expected CorruptedError")
 
@@ -371,9 +415,9 @@ class FileStorageTests(
             # FileStorage.TransactionRecord or hexstorage.Transaction
             trec = v[0]
             self.assertEqual(trec.tid, head)
-            self.assertEqual(trec.user,          b'')
-            self.assertEqual(trec.description,   description.encode('utf-8'))
-            self.assertEqual(trec.extension,     {})
+            self.assertEqual(trec.user, b'')
+            self.assertEqual(trec.description, description.encode('utf-8'))
+            self.assertEqual(trec.extension, {})
             drecv = list(trec)
             self.assertEqual(drecv, [])
 
